==> haskell-mono-traversable-1.0.11.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.11.0
id: mono-traversable-1.0.11.0-7wTGuRnUOeRZkWG4soGMC
key: mono-traversable-1.0.11.0-7wTGuRnUOeRZkWG4soGMC
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, John Wiegley, Greg Weber
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>
category: Data
abi: b6c099c916c705ea1c2ce490e1c29eab
exposed: True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences
hidden-modules: Paths_mono_traversable
import-dirs: /usr/lib/ghc-8.6.4/site-local/mono-traversable-1.0.11.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/mono-traversable-1.0.11.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/mono-traversable-1.0.11.0
hs-libraries: HSmono-traversable-1.0.11.0-7wTGuRnUOeRZkWG4soGMC
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    split-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    vector-algorithms-0.8.0.1-zLqoLOQvkRBhoAdmbhXfr
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.11.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.11.0
id: mono-traversable-1.0.11.0-IgegpBJOLQXCoQoQvscnoM
key: mono-traversable-1.0.11.0-IgegpBJOLQXCoQoQvscnoM
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, John Wiegley, Greg Weber
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>
category: Data
abi: b7f9f6afe9b6070316d1aa34d3620c15
exposed: True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences
hidden-modules: Paths_mono_traversable
import-dirs: /usr/lib/ghc-8.6.4/site-local/mono-traversable-1.0.11.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/mono-traversable-1.0.11.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/mono-traversable-1.0.11.0
hs-libraries: HSmono-traversable-1.0.11.0-IgegpBJOLQXCoQoQvscnoM
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    split-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    vector-algorithms-0.8.0.1-zLqoLOQvkRBhoAdmbhXfr
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
